require 'lexers.csv'
require 'ex'
local filefind = require 'filefind'
require 'p4'

paths = require 'octane.pathconfig'.load()

p4 = P4.P4()

p4:connect()
--print( 'p4.client = ' .. p4.client .. '\n' )

local byPlayset = nil
local category = nil
local subType = nil

local buf = {};

local allfiles = {}
for entry in filefind.glob(os.path.combine(paths.ContentGame, 'ActorList', 'Default', '*.lua')) do
	allfiles[#allfiles + 1] = entry.filename
end


function StartFile()
	buf[#buf + 1] = '#==============================================================================\n'
	buf[#buf + 1] = '#\n'
	buf[#buf + 1] = '#	Meridian_ActorCreationData.tup: AUTO-GENERATED. DO NOT HAND EDIT!\n'
	buf[#buf + 1] = '#\n'
	buf[#buf + 1] = '#==============================================================================\n\n\n'
	buf[#buf + 1] = 'Items "ActorCreationDB" =\n'
	buf[#buf + 1] = '{\n'
end


function EndFile()
	buf[#buf + 1] = '}\n'
end


function StartItemList( name )
	-- Write out the header
	buf[#buf + 1] = '	Item "' .. name ..'" =\n'
	buf[#buf + 1] = '	{\n'
	buf[#buf + 1] = '		Selectable = 0\n'
end


function EndItemList()
	buf[#buf + 1] = '	}\n'
end


function GetItems()
	if byPlayset == nil then
		StartItemList( 'Core' )
	end
	
	local sortedNameTable = {}

	-- loop through all files
	for i=1,#allfiles do
		local curFile = allfiles[i]
		print( curFile .. '\n' )

		-- load and process the current file
		dofile( allfiles[i] )
		
		if byPlayset ~= nil then
			sortedNameTable = {}
			StartItemList( Data.PlaysetName )
		end

		for type,v in pairs(Data.Actors) do
			if category == nil and subType == nil then
				-- Get everything
				for _,item in ipairs( v ) do
					sortedNameTable[#sortedNameTable + 1] = item.Name
				end
			elseif type == category then
				-- Get everything in this category (subTable)
				for _,item in ipairs( v ) do
					sortedNameTable[#sortedNameTable + 1] = item.Name
				end
			elseif subType ~= nil then
				-- Get each item if the subType matches
				for _,item in ipairs( v ) do
					if item.SubType == subType then
						sortedNameTable[#sortedNameTable + 1] = item.Name
					end
				end
			end
		end
		
		if byPlayset ~= nil then
			table.sort( sortedNameTable )
			for k,v in ipairs(sortedNameTable) do
				if v ~= nil then
					buf[#buf + 1] = '		Item "' .. v .. '" = { On "Selected" = { SetNodeText = "' .. v .. '" } }\n'
				end
			end
			EndItemList()
		end
		
	end
	
	if byPlayset == nil then
		table.sort( sortedNameTable )
		for k,v in ipairs(sortedNameTable) do
			if v ~= nil then
				buf[#buf + 1] = '		Item "' .. v .. '" = { On "Selected" = { SetNodeText = "' .. v .. '" } }\n'
			end
		end
		
		EndItemList()
	end
end


function WriteDataToFile( filenameEnd )
	buf = table.concat(buf)
	local filename = os.path.combine(paths.ContentGame, 'meridian', 'Meridian_ActorCreationData')
	if filenameEnd ~= nil then
		filename = filename .. '_' .. filenameEnd
	end
	filename = filename .. '.tup'

	local fileBuffer = io.readall(filename)
	if fileBuffer == buf then
		print( 'No change to file: '.. filename .. '\n' )
	else
		-- the new data is different than the old data. checkout the file and write to it.
		p4:connect()
		p4.exception_level = 0
		if fileBuffer == nil then
			print( 'Writing file: '.. filename ..'...\n')
			io.writeall( filename, buf)
			print( 'Adding file: '.. filename ..'...\n')
			p4:run( "add", filename )
		else
			print( 'Checking out file: '.. filename ..'...\n')
			p4:run( "sync", '-f', filename )
			p4:run( "edit", filename )
			print( 'Writing file: '.. filename ..'...\n')
			io.writeall( filename, buf)
		end

		p4:disconnect()
	end
end


-- GetArgs():
--       Get the arguments passed in.
--
--    Parameters
--       -p                   Output the data in playset tables
--       -c  CategoryName     For example -c Vehicle   (the table name)
--       subType
--
--       If no parameters are present then all items are sorted and output in one table
function GetArgs()
	local bCategory = false

	for i=2, #arg do
		if arg[i] == "-p" then
			byPlayset = true
		elseif arg[i] == "-c" then
			bCategory = true
		elseif bCategory == true then
			category = arg[i]
			bCategory = false
		else
			subType = arg[i]
		end
	end

	if byPlayset == nil then
		print "Not by playset"
	else
		print "By playset"
	end
	
	if category == nil then
		print "No category"
	else
		print( "Category = " .. category )
	end

	if subType == nil then
		print "No Subtype"
	else
		print ("Subtype = " .. subType)
	end
end


function Main()
	GetArgs()

	StartFile()
	GetItems()
	
	if category ~= nil then
		fileSuffix = category
	else
		fileSuffix = subType
	end
	
	EndFile()
	WriteDataToFile( fileSuffix )
end

Main()