---------------------------[ RumpusScenario ] -----------------------------------
--
-- This system was created to set specific recipe card and inventory availability for a gameplay scenario, based on world name
-- 
-- The intended use is for the game to save state before entering a scenario, setting the inventory
-- and recipe card configuation needed for the scenario, allowing the scenario to play out, returning to 
-- main game and then forcing a save game load to restore the previous inventory state. 
--
-- ONE SHOULD NOT ALLOW SAVE GAMES TO HAPPEN DURING AN ADVENTURE OTHERWISE USER DATA WILL GET LOST!
--
-- The useage of this file is simple, within the Data section one creates a new data section with the same 
-- name as the scenario world name (holoEmpty for example). Within that world name section there are multiple 
-- commands and sections to set the state of various things. Non-Programmers may need to consult with a programmer
-- to get the proper lock names or stat set names depending on what data they want to setup. Only data that matches
-- the current level name will be used
--
-- COMMANDS: 
--	HIDE_ALL_INVENTORY - removes all inventory items from inventory ribbon, does NOT change availibility or count to existing items
-- 	SHOW_ALL_INVENTORY - adds all inventory items to the inventory ribbon, does NOT change availibility or count of existing items
--	LOCK_ALL_INVENTORY - locks all inventory, sets availability count to 0
-- 	UNLOCK_ALL_INVENTORY - unlocks all inventory items and assigns a availablity count of 1
--	SET_LOCKS_BY_TYPE - takes a type of lock, and sets it to the specificed state
--	PURCHASE_ALL_UNLOCKED_RECIPECARDS - will purchase all items for all unlocked recipe cards
--	RIBBON_SELECT - given an inventory item name, the ribbon will come up with this item selected initially
--
-- LOCKS:
--	Given a lock name, it will set it to the specified state
--
-- STATS:
--	Given the stat set name, and stat name, it will set the stat to the value specified
--
-- INVENTORY_ITEM_STATE:
-- 	Given an inventory item name, it will set the state and count to what is specified.
--    Enabled=0 (don't show even if unlocked), 1 (show if unlocked), 2 (show even if locked)
--
-- MIX_RECIPE_CARDS:
--	Given a recipe card name, it will purchase and mix this card.
-- 
--
-- Recommended usage:
-- 	To keep things simple, in most cases for a scenario or test case, one should use the commands to 
-- 	make everything unavailable, then set specific things to be available. 



Data = 
{
	INVENTORY_ITEM_STATE = 	
	{
		{ name="INV_Toy_EnemyWorldSpawner",			enabled=0  },
		{ name="INV_Toy_SkyDomeToy",			enabled=0  },

		{ name="INV_BLOCK_CUBE",				enabled=2  },
		{ name="INV_BLOCK_RECT",				enabled=2  },
		{ name="INV_BLOCK_WALL",				enabled=2  },
		{ name="INV_BLK_Wedge_1X1_A",				enabled=2  },
		{ name="INV_BLOCK_WEDGE",				enabled=2  },
		{ name="INV_BLK_Ramp_4x4",				enabled=2  },
		{ name="INV_BLOCK_LEDGEGRAB",				enabled=2  },
		{ name="INV_BLK_Ledge_Corner_1X1_A",			enabled=2  },
		{ name="INV_BLOCK_ARCH",				enabled=2  },
		{ name="INV_BLOCK_PILLAR",				enabled=2  },
		{ name="INV_BLOCK_SEMI_CIRCLE",				enabled=2  },
		{ name="INV_BLOCK_TRIANGLE",				enabled=2  },
		{ name="INV_Block_ArcadeRound",				enabled=2  },
		{ name="INV_Block_ArcadeVaulted",			enabled=2  },
		{ name="INV_Block_Balcony",				enabled=2  },
		{ name="INV_Block_ButtressLong",			enabled=2  },
		{ name="INV_Block_ButtressShort",			enabled=2  },
		{ name="INV_Block_Column",				enabled=2  },
		{ name="INV_Block_DipBeam",				enabled=2  },
		{ name="INV_Block_FullDome",				enabled=2  },
		{ name="INV_Block_HalfDome",				enabled=2  },
		{ name="INV_Block_OnionDome",				enabled=2  },
		{ name="INV_Block_Obelisk",				enabled=2  },
		{ name="INV_Block_RampVertical",			enabled=2  },
		{ name="INV_Block_Trim",				enabled=2  },
		{ name="INV_Block_Stairs",				enabled=2  },
		{ name="INV_BLD_DNG_Floor_4X1X4_A",			enabled=2  },
		{ name="INV_BLD_DNG_Floor_12X1X12_A",			enabled=2  },
		{ name="INV_BLD_DNG_Wall_4X4X1_A",			enabled=2  },
		{ name="INV_BLD_DNG_Wall_4X12X1_A",			enabled=2  },
		{ name="INV_BLD_DNG_Wall_12X12X1_A",			enabled=2  },
		{ name="INV_BLD_DNG_WallCrnr_4X12X4_A",			enabled=2  },
		{ name="INV_PHYSICSBLOCK_GLASS_S",			enabled=2  },
		{ name="INV_PHYSICSBLOCK_GLASS_V",			enabled=2  },
		{ name="INV_PHYSICSBLOCK_GLASS_H",			enabled=2  },
		{ name="INV_PHYSICSBLOCK_WOOD_S",			enabled=2  },
		{ name="INV_PHYSICSBLOCK_WOOD_V",			enabled=2  },
		{ name="INV_PHYSICSBLOCK_WOOD_H",			enabled=2  },
		{ name="INV_PHYSICSBLOCK_METAL_S",			enabled=2  },
		{ name="INV_PHYSICSBLOCK_METAL_V",			enabled=2  },
		{ name="INV_PHYSICSBLOCK_METAL_H",			enabled=2  },
		{ name="INV_PHYSICSBLOCK_EXPLOSIVE",			enabled=2  },
		{ name="INV_TB_Wood_Wall",				enabled=2  },
		{ name="INV_TB_Brick_Wall",				enabled=2  },
		{ name="INV_TB_Concrete_Wall",				enabled=2  },
		{ name="INV_Challenge_HitOrb_Blue",			enabled=2  },
		{ name="INV_Challenge_HitOrb_Gold",			enabled=2  },
		{ name="INV_Challenge_HitOrb_Green",			enabled=2  },
		{ name="INV_Challenge_Orb_Blue",			enabled=2  },
		{ name="INV_Challenge_Orb_Gold",			enabled=2  },
		{ name="INV_Challenge_Orb_Green",			enabled=2  },
		{ name="INV_Challenge_Ring_Blue",			enabled=2  },
		{ name="INV_Challenge_Ring_Gold",			enabled=2  },
		{ name="INV_Challenge_Ring_Green",			enabled=2  },
		{ name="INV_BLK_DVL_Door_4X4X1_A",			enabled=2  },
		{ name="INV_BLK_DVL_Door_4X8X1_A",			enabled=2  },
		{ name="INV_BLK_DVL_Door_8X8X1_A",			enabled=2  },
		{ name="INV_Toy_BeachBall",				enabled=2  },
		{ name="INV_Toy_Boulder",				enabled=2  },
		{ name="INV_Toy_Snowball_Large",			enabled=2  },
		{ name="INV_BLK_PipeClimb_4X4X12",			enabled=2  },
		{ name="INV_BLK_PipeClimb_8_A",				enabled=2  },
		{ name="INV_BLK_PipeClimb_4_A",				enabled=2  },
		{ name="INV_BLK_PipeClimb_12_A",			enabled=2  },
		{ name="INV_BLOCK_MovingWall_4X12X12_A",		enabled=2  },
		{ name="INV_Toy_ConveyerBelt",				enabled=2  },
		{ name="INV_TRK_Rail_Straight",				enabled=2  },
		{ name="INV_TRK_Rail_StraightShort",			enabled=2  },
		{ name="INV_TRK_Rail_Bump",				enabled=2  },
		{ name="INV_TRK_Rail_Curve",				enabled=2  },
		{ name="INV_TRK_Rail_Dip",				enabled=2  },
		{ name="INV_TRK_Rail_Jog",				enabled=2  },
		{ name="INV_TRK_Rail_Jog_B",				enabled=2  },
		{ name="INV_TRK_Rail_Ramp",				enabled=2  },
		{ name="INV_TRK_Rail_Ramp_Sharp",			enabled=2  },
		{ name="INV_TRK_Rail_Ramp_CurveSharpL",			enabled=2  },
		{ name="INV_TRK_Rail_Ramp_CurveSharpR",			enabled=2  },
		{ name="INV_TRK_Rail_RampBlend_A",			enabled=2  },
		{ name="INV_TRK_Rail_RampBlend_B",			enabled=2  },
		{ name="INV_TRAK_4_pipe_to_rail",			enabled=2  },
		{ name="INV_TRK_Rail_Spiral_A",				enabled=2  },
		{ name="INV_TRK_Rail_Switch_straight_A",		enabled=2  },
		{ name="INV_TB_LH_Clip_2_B",				enabled=2  },
		{ name="INV_TB_LH_Clip_4_A",				enabled=2  },
		{ name="INV_TB_LH_Clip_Rotate_4_A",			enabled=2  },
		{ name="INV_TB_LH_Clip_SideMove_12_A",			enabled=2  },
		{ name="INV_TB_LH_Clip_UpMove_12_A",			enabled=2  },
		{ name="INV_TB_LH_Clip_UpMove_4_A",			enabled=2  },
		{ name="INV_TB_LH_Clip_inside_90_A",			enabled=2  },
		{ name="INV_TB_LH_Clip_inside_90_C",			enabled=2  },
		{ name="INV_TB_LH_Clip_outer_90_A",			enabled=2  },
		{ name="INV_TB_LH_Clip_outer_90_C",			enabled=2  },
		{ name="INV_TB_LH_Clip_slantDown_B",			enabled=2  },
		{ name="INV_TB_LH_Clip_slantUp_B",			enabled=2  },
		{ name="INV_Ladder_small",				enabled=2  },
		{ name="INV_Ladder_medium",				enabled=2  },
		{ name="INV_Ladder_large",				enabled=2  },
		{ name="INV_Bridge_platform",				enabled=2  },
		{ name="INV_Bridge_small",				enabled=2  },
		{ name="INV_Bridge_medium",				enabled=2  },
		{ name="INV_Bridge_large",				enabled=2  },
		{ name="INV_Bridge_small_B",				enabled=2  },
		{ name="INV_Bridge_medium_B",				enabled=2  },
		{ name="INV_TOY_ALA_FallingBridge",			enabled=2  },
		{ name="INV_POP_DC_Ropebridge",				enabled=2  },
		{ name="INV_POP_DC_Ropebridge_Wide",			enabled=2  },
		{ name="INV_TOY_ALA_RopeClimb_4M",			enabled=2  },
		{ name="INV_TOY_ALA_RopeClimb_8M",			enabled=2  },
		{ name="INV_TOY_ALA_RopeClimb_24M",			enabled=2  },
		{ name="INV_TOY_ALA_TimedPlatform",			enabled=2  },
		{ name="INV_TOY_ALA_Trampoline",			enabled=2  },
		{ name="INV_BLOCK_ELEVATOR",				enabled=2  },
		{ name="INV_BLOCK_FLIPPING_PLATFORM",			enabled=2  },
		{ name="INV_BLOCK_SPINNER",				enabled=2  },
		{ name="INV_BLOCK_SPINNER_LRG",				enabled=2  },
		{ name="INV_BLOCK_Pendulum_4X12X12_A",			enabled=2  },
		{ name="INV_TOY_UpVent",				enabled=2  },
		{ name="INV_Toy_DungeonCamera",				enabled=2  },
		{ name="INV_Toy_ButtonMapper",				enabled=2  },
		{ name="INV_PHYSICSBLOCK_RESET_TOY",			enabled=2  },
		{ name="INV_Toy_Locator",				enabled=2  },
		{ name="INV_Toy_AvatarAction",				enabled=2  },
		{ name="INV_Toy_Collector",				enabled=2  },
		{ name="INV_Toy_Triggerplate",				enabled=2  },
		{ name="INV_TOY_TriggerVolume",				enabled=2  },
		{ name="INV_Toy_Button",				enabled=2  },
		{ name="INV_Toy_Target",				enabled=2  },
		{ name="INV_TOY_RaceGate",				enabled=2  },
		{ name="INV_TOY_FetchPen",				enabled=2  },
		{ name="INV_TOY_CheckPoint",				enabled=2  },
		{ name="INV_TOY_PickupSpawner",				enabled=2  },
		{ name="INV_TOY_DropSpawner",				enabled=2  },
		{ name="INV_TOY_TIMER",					enabled=2  },
		{ name="INV_Toy_Counter",				enabled=2  },
		{ name="INV_Template_CheckPointRace_FleshedOut",	enabled=2  },
		{ name="INV_Template_redLightGreenLight",		enabled=2  },
		{ name="INV_Template_CheckPointRace",			enabled=2  },
		{ name="INV_Template_VehicularCombatGame",		enabled=2  },
		{ name="INV_Template_WeatherVane_Volume",		enabled=2  },
		{ name="INV_Template_SmashArena_A",			enabled=2  },
		{ name="INV_Template_SmashArena_B",			enabled=2  },
		{ name="INV_Template_SmashArena_C",			enabled=2  },
		{ name="INV_TRAK_16_StraightX4",			enabled=2  },
		{ name="INV_TRAK_16_StraightX12",			enabled=2  },
		{ name="INV_TRAK_16_StraightX24",			enabled=2  },
		{ name="INV_TRAK_16_StraightX48",			enabled=2  },
		{ name="INV_TRAK_16_Straight_RaceStart",		enabled=2  },
		{ name="INV_TRAK_16_Y_Split",				enabled=2  },
		{ name="INV_TRAK_16_Y_Junction",			enabled=2  },
		{ name="INV_TRAK_16_JogLeft",				enabled=2  },
		{ name="INV_TRAK_16_JogRight",				enabled=2  },
		{ name="INV_TRAK_16_short_JogLeft",			enabled=2  },
		{ name="INV_TRAK_16_short_JogRight",			enabled=2  },
		{ name="INV_TRAK_16_Ramp_SteepStart",			enabled=2  },
		{ name="INV_TRAK_16_Ramp_Steep",			enabled=2  },
		{ name="INV_TRAK_16_Ramp_SteepEnd",			enabled=2  },
		{ name="INV_TRAK_16_Bridge",				enabled=2  },
		{ name="INV_TRAK_16_CurveRiseA_R",			enabled=2  },
		{ name="INV_TRAK_16_CurveRiseA_L",			enabled=2  },
		{ name="INV_TRAK_16_BurmCurveA",			enabled=2  },
		{ name="INV_TRAK_16_BurmCurve180_A",			enabled=2  },
		{ name="INV_TRAK_16_Ramp_AbruptStart",			enabled=2  },
		{ name="INV_TRAK_16_Ramp_AbruptEnd",			enabled=2  },
		{ name="INV_BLOCK_TRACK_Straight_Short",		enabled=2  },
		{ name="INV_BLOCK_TRACK_Straight_Long",			enabled=2  },
		{ name="INV_BLOCK_TRACK_CurveA",			enabled=2  },
		{ name="INV_BLOCK_TRACK_CurveB",			enabled=2  },
		{ name="INV_BLOCK_TRACK_Ramp_Abrupt",			enabled=2  },
		{ name="INV_BLOCK_TRACK_RampA",				enabled=2  },
		{ name="INV_TRK_HalfLoop_12x24x24",			enabled=2  },
		{ name="INV_TRK_SmallLoop_16x32x16",			enabled=2  },
		{ name="INV_TRACK_LAUNCHRAMP",				enabled=2  },
		{ name="INV_TRACK_QUARTERPIPE",				enabled=2  },
		{ name="INV_TRACK_BOOSTPAD",				enabled=2  },
		{ name="INV_TRACK_FIREHOOP",				enabled=2  },
		{ name="INV_BLK_INV_COL_16Curve_A",			enabled=2  },
		{ name="INV_BLK_INV_COL_16Curve_B",			enabled=2  },
		{ name="INV_BLK_INV_COL_16_JogLeft",			enabled=2  },
		{ name="INV_BLK_INV_COL_16_JogRight",			enabled=2  },
		{ name="INV_BLK_INV_COL_16_NinetyA30_B",		enabled=2  },
		{ name="INV_BLK_INV_COL_16_NinetyA_A",			enabled=2  },
		{ name="INV_BLK_INV_COL_16_Y_Junction_A",		enabled=2  },
		{ name="INV_BLK_INV_COL_16_Y_Junction_B",		enabled=2  },
		{ name="INV_BLK_INV_COL_16_Y_Split_A",			enabled=2  },
		{ name="INV_BLK_INV_COL_16_Y_Split_B",			enabled=2  },
		{ name="INV_BLK_INV_COL_32Curve_B",			enabled=2  },
		{ name="INV_BLK_INV_COL_32_A",				enabled=2  },
		{ name="INV_BLK_INV_COL_32_JogLeft",			enabled=2  },
		{ name="INV_BLK_INV_COL_32_JogRight",			enabled=2  },
		{ name="INV_BLK_INV_COL_32_NinetyA30_B",		enabled=2  },
		{ name="INV_BLK_INV_COL_32_NinetyA_A",			enabled=2  },
		{ name="INV_BLK_INV_COL_32_Y_Junction_A",		enabled=2  },
		{ name="INV_BLK_INV_COL_32_Y_Junction_B",		enabled=2  },
		{ name="INV_BLK_INV_COL_32_Y_Split_A",			enabled=2  },
		{ name="INV_BLK_INV_COL_32_Y_Split_B",			enabled=2  },
		{ name="INV_TOY_SOCCERBALL",				enabled=2  },
		{ name="INV_TOY_SOCCER_GOAL",				enabled=2  },
		{ name="INV_TOY_Basketball",				enabled=2  },
		{ name="INV_TOY_BasketballHoop",			enabled=2  },
		{ name="INV_TOY_Football",				enabled=2  },
		{ name="INV_TOY_Goalpost",				enabled=2  },
		{ name="INV_Toy_Golfball",				enabled=2  },
		{ name="INV_TOY_Tennisball",				enabled=2  },
		{ name="INV_TOY_Baseball",				enabled=2  },
		{ name="INV_TOY_BOWLINGBALL",				enabled=2  },
		{ name="INV_Toy_HockeyPuck",				enabled=2  },
		{ name="INV_SPD_Car_Taxi",				enabled=2  },
		{ name="INV_SPD_Car_Black",				enabled=2  },
		{ name="INV_SPD_Car_Blue",				enabled=2  },
		{ name="INV_SPD_Car_Police",				enabled=2  },
		{ name="INV_POP_CTY_Walkway4_curve",			enabled=2  },
		{ name="INV_POP_CTY_Walkway4_end",			enabled=2  },
		{ name="INV_POP_CTY_Walkway4_straight",			enabled=2  },
		{ name="INV_POP_CTY_Walkway4_T",			enabled=2  },
		{ name="INV_POP_TB_Arrow_UpDown_blue",			enabled=2  },
		{ name="INV_POP_TB_Arrow_Ground_blue",			enabled=2  },
		{ name="INV_POP_TB_Xmark_wall_blue",			enabled=2  },
		{ name="INV_POP_TB_Xmark_Ground_blue",			enabled=2  },
		{ name="INV_POP_TB_Xmark_wall_blue",			enabled=2  },
		{ name="INV_POP_TB_Xmark_Ground_blue",			enabled=2  },
		{ name="INV_POP_TB_Danger_wall_blue",			enabled=2  },
		{ name="INV_POP_TB_Danger_Ground_blue",			enabled=2  },
		{ name="INV_POP_DC_ClusterEdgeMed_A",			enabled=2  },
		{ name="INV_POP_DC_ClusterEdgeSm_A",			enabled=2  },
		{ name="INV_POP_DC_ClusterSingleTreeHuge_A",		enabled=2  },
		{ name="INV_POP_DC_ClusterSingleTreeSm_A",		enabled=2  },
		{ name="INV_POP_DC_ClusterSmall_A",			enabled=2  },
		{ name="INV_POP_DC_ClusterStripA",			enabled=2  },
		{ name="INV_POP_DC_ClusterStripB",			enabled=2  },
		{ name="INV_POP_DC_ClusterCornerLrg_A",			enabled=2  },
		{ name="INV_POP_DC_ClusterCornerMed_A",			enabled=2  },
		{ name="INV_Leafy",					enabled=2  },
		{ name="INV_POP_DC_Flower_groundcluster",		enabled=2  },
		{ name="INV_POP_DC_Flower_large",			enabled=2  },
		{ name="INV_POP_DC_Flower_purpleclump",			enabled=2  },
		{ name="INV_POP_DC_Bush_A",				enabled=2  },
		{ name="INV_POP_DC_Bush_B",				enabled=2  },
		{ name="INV_POP_DC_Pine_A",				enabled=2  },
		{ name="INV_POP_DC_Pine_B",				enabled=2  },
		{ name="INV_POP_DC_Pine_C",				enabled=2  },
		{ name="INV_BRS_TrackBrushStart",			enabled=2  },
		{ name="INV_BRS_TreehouseBrushStart",			enabled=2  },
		{ name="INV_BRS_cityStamp",				enabled=2  },
		{ name="INV_BRS_PlatformerPin",				enabled=2  },
		{ name="INV_BRS_RailSlidePin",				enabled=2  },
		{ name="INV_BRS_CastleKeepPin",				enabled=2  },
		{ name="INV_BRS_PirateHouse_BrushHead",			enabled=2  },
		{ name="INV_BRS_TreeHouse_BrushHead",			enabled=2  },
		{ name="INV_BRS_CastleWall_BrushHead",			enabled=2  },
		{ name="INV_BRS_Forest_BrushHead",			enabled=2  },
		{ name="INV_BRS_RailSlide_BrushHead",			enabled=2  },
		{ name="INV_BRS_Agrabah_BrushHead",			enabled=2  },
		{ name="INV_NPC_RR_BEAR",				enabled=2  },
		{ name="INV_NPC_RR_BIRD",				enabled=2  },
		{ name="INV_NPC_RR_BUCK",				enabled=2  },
		{ name="INV_NPC_RR_DEER",				enabled=2  },
		{ name="INV_NPC_RR_FROG",				enabled=2  },
		{ name="INV_NPC_RR_GOPHER",				enabled=2  },
		{ name="INV_NPC_RR_RABBIT",				enabled=2  },
		{ name="INV_NPC_RR_RAT",				enabled=2  },
		{ name="INV_NPC_RR_WOLF",				enabled=2  },
		{ name="INV_TB_Elephant",				enabled=2  },
		{ name="INV_NPC_RR_INC_GIRAFFE",			enabled=2  },
		{ name="INV_NPC_RR_INC_LION",				enabled=2  },
		{ name="INV_NPC_RR_INC_MONKEY",				enabled=2  },
		{ name="INV_NPC_RR_INC_PANDA",				enabled=2  },
		{ name="INV_NPC_RR_INC_PENGUIN",			enabled=2  },
		{ name="INV_NPC_FG_Grunt_I",				enabled=2  },
		{ name="INV_NPC_FG_Grunt_II",				enabled=2  },
		{ name="INV_NPC_FG_Melee_I",				enabled=2  },
		{ name="INV_NPC_FG_Melee_II",				enabled=2  },
		{ name="INV_NPC_FG_Ranged_I",				enabled=2  },
		{ name="INV_NPC_FG_TankMelee",				enabled=2  },
		{ name="INV_NPC_AIM_Battlepod",				enabled=2  },
		{ name="INV_NPC_Sym_Swarmer_Melee",			enabled=2  },
		{ name="INV_NPC_Sym_Grunt_Block",			enabled=2  },
		{ name="INV_NPC_Sym_Grunt_Dodge",			enabled=2  },
		{ name="INV_NPC_Sym_Grunt_Ranged",			enabled=2  },
		{ name="INV_NPC_Sym_Tank_Vomit",			enabled=2  },
		{ name="INV_NPC_RR_CARDS_CLUB",				enabled=2  },
		{ name="INV_NPC_RR_CARDS_HEART",			enabled=2  },
		{ name="INV_NPC_TB_TANGLED_GUARD",			enabled=2  },
		{ name="INV_NPC_TB_ALADDIN_GUARD",			enabled=2  },
		{ name="INV_NPC_TB_RHINO_GUARD",			enabled=2  },
		{ name="INV_NPC_OMNIDROID",				enabled=2  },
		{ name="INV_NPC_OMNIDROID_MELEE_II",			enabled=2  },
		{ name="INV_NPC_OMNIDROID_RANGED_I",			enabled=2  },
		{ name="INV_NPC_SK_Kyln_Prisoner1",			enabled=2  },
		{ name="INV_NPC_SK_Kyln_Prisoner2",			enabled=2  },
		{ name="INV_NPC_SK_Brave_MacintoshJr",			enabled=2  },
		{ name="INV_NPC_SK_Brave_MacGuffinJr",			enabled=2  },
		{ name="INV_NPC_RR_AgentCoulson",			enabled=2  },
		{ name="INV_NPC_RR_Antman",				enabled=2  },
		{ name="INV_NPC_RR_BetaRayBill",			enabled=2  },
		{ name="INV_NPC_RR_BlackWidow",				enabled=2  },
		{ name="INV_NPC_RR_CaptainAmerica",			enabled=2  },
		{ name="INV_NPC_RR_ANNA",				enabled=2  },
		{ name="INV_NPC_RR_ELSA",				enabled=2  },
		{ name="INV_NPC_RR_JACK_SKELLINGTON",			enabled=2  },
		{ name="INV_NPC_INC_Boy",				enabled=2  },
		{ name="INV_NPC_INC_Girl",				enabled=2  },
		{ name="INV_NPC_INC_BusinessMan01",			enabled=2  },
		{ name="INV_NPC_INC_BusinessMan02",			enabled=2  },
		{ name="INV_NPC_INC_ConstructionWorker",		enabled=2  },
		{ name="INV_AVG_Stark_SportsCar",			enabled=2  },
		{ name="INV_AVG_SHLD_Motorcycle",			enabled=2  },
		{ name="INV_TB_Sven",					enabled=2  },
		{ name="INV_TB_AutopiaCar",				enabled=2  },
		{ name="INV_VEHICLE_STUNT_CAR",				enabled=2  },
		{ name="INV_VEHICLE_ATTACK_COPTER",			enabled=2  },
		{ name="INV_LR_Mule",					enabled=2  },
		{ name="INV_LR_Wildhorse_Black",			enabled=2  },
		{ name="INV_SETPIECE_AVG_StarkTower",			enabled=2  },
		{ name="INV_DarkTower",					enabled=2  },
		{ name="INV_SETPIECE_Dungeon",				enabled=2  },
		{ name="INV_SETPIECE_PIR_arch",				enabled=2  },
		{ name="INV_SETPIECE_IncBuildingA",			enabled=2  },
		{ name="INV_SETPIECE_IncBuildingB",			enabled=2  },
		{ name="INV_SETPIECE_IncBuildingC",			enabled=2  },
		{ name="INV_SETPIECE_IncBuildingD",			enabled=2  },
		{ name="INV_SETPIECE_IncBuildingE",			enabled=2  },
		{ name="INV_SETPIECE_IncBuildingF",			enabled=2  },
		{ name="INV_SETPIECE_IncBuildingG",			enabled=2  },
		{ name="INV_TB_TH_Branch_4x4",				enabled=2  },
		{ name="INV_TB_TH_Branch_90",				enabled=2  },
		{ name="INV_TB_TH_Branch_Big",				enabled=2  },
		{ name="INV_TB_TH_Branch_Small",			enabled=2  },
		{ name="INV_TB_TH_Branch_Sright",			enabled=2  },
		{ name="INV_TB_TH_Branch_straight",			enabled=2  },
		{ name="INV_TB_TH_Bridge_down",				enabled=2  },
		{ name="INV_TB_TH_Building_8x8",			enabled=2  },
		{ name="INV_TB_TH_Building_8x8open",			enabled=2  },
		{ name="INV_TB_TH_Building_Balcony_Ship",		enabled=2  },
		{ name="INV_TB_TH_Building_balcony_Small",		enabled=2  },
		{ name="INV_TB_TH_Building_Curvedwindows",		enabled=2  },
		{ name="INV_TB_TH_Building_Light_Ground",		enabled=2  },
		{ name="INV_TB_TH_Building_Light_Wall",			enabled=2  },
		{ name="INV_TB_TH_Building_Platform",			enabled=2  },
		{ name="INV_TB_TH_Building_Platform_withroof",		enabled=2  },
		{ name="INV_TB_TH_Building_Roof_Tall",			enabled=2  },
		{ name="INV_TB_TH_Building_Roof_Thatched",		enabled=2  },
		{ name="INV_TB_TH_Canopy_4x4",				enabled=2  },
		{ name="INV_TB_TH_Canopy_Big",				enabled=2  },
		{ name="INV_TB_TH_Canopy_ropeclimb",			enabled=2  },
		{ name="INV_TB_TH_Canopy_Small",			enabled=2  },
		{ name="INV_TB_TH_HiddenDoorToy1",			enabled=2  },
		{ name="INV_TB_TH_Platform_12x8_curved",		enabled=2  },
		{ name="INV_TB_TH_Platform_4x8",			enabled=2  },
		{ name="INV_TB_TH_Platform_8x8_corner",			enabled=2  },
		{ name="INV_TB_TH_Platform_Crowsnest",			enabled=2  },
		{ name="INV_TB_TH_Platform_ropeclimb",			enabled=2  },
		{ name="INV_TB_TH_Roots",				enabled=2  },
		{ name="INV_TB_TH_Stair_Spiral",			enabled=2  },
		{ name="INV_TB_TH_Stair_Straight",			enabled=2  },
		{ name="INV_TB_TH_Trunk_12x12",				enabled=2  },
		{ name="INV_TB_TH_Trunk_Circle_quarter_12x12",		enabled=2  },
		{ name="INV_TB_TH_Trunk_halfcircle_12x4",		enabled=2  },
		{ name="INV_TB_TH_Trunk_Round_8x8",			enabled=2  },
		{ name="INV_TerrainBlock_Castle_12x4x4",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_12x8x8",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_12X12",			enabled=2  },
		{ name="INV_TerrainBlock_Castle_24X24",			enabled=2  },
		{ name="INV_TerrainBlock_Castle_48X48",			enabled=2  },
		{ name="INV_TerrainBlock_Castle_96X96",			enabled=2  },
		{ name="INV_TerrainBlock_Castle_12x12x24",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_12x24x24",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_12x48x48",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_12x48x96",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_12x96x96",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_48X12X96",		enabled=2  },
		{ name="INV_TER_ClipPlat_corner_24X24_B",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_Slope_12X12",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_SlopeB_24X24",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_Slope_24X24",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_CornerSlope_24X24",	enabled=2  },
		{ name="INV_TerrainBlock_Castle_Slope_48X48",		enabled=2  },
		{ name="INV_TER_CubeRamp",				enabled=2  },
		{ name="INV_TerrainBlock_Castle_SmallSideClip",		enabled=2  },
		{ name="INV_TER_ClipBase_28x12x24_A",			enabled=2  },
		{ name="INV_TER_ClipBase_28x28x36_A",			enabled=2  },
		{ name="INV_TER_ClipBase_24x24x24_Ramp",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_Cavefort",		enabled=2  },
		{ name="INV_TER_ClipPlat_12x8x12_A",			enabled=2  },
		{ name="INV_TER_ClipPlat_12x_B",			enabled=2  },
		{ name="INV_TER_ClipPlat_12X_A",			enabled=2  },
		{ name="INV_TER_ClipPlat_12X24X24_A",			enabled=2  },
		{ name="INV_TerrainBlock_Castle_Cliffclimb",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_LedgehangClip1",	enabled=2  },
		{ name="INV_TER_LedgeRope_8X12X12",			enabled=2  },
		{ name="INV_TerrainBlock_Castle_LargeCornerClip",	enabled=2  },
		{ name="INV_TER_Clip_CornerConvex",			enabled=2  },
		{ name="INV_TerrainBlock_Castle_SmallCornerClip",	enabled=2  },
		{ name="INV_TER_Clip_UnderHangEdge_12x_A",		enabled=2  },
		{ name="INV_TER_Clip_UnderHangCorner_12x_A",		enabled=2  },
		{ name="INV_TER_ClipPerch_4x_A",			enabled=2  },
		{ name="INV_Ter_ClipPerch_4x4x8_A",			enabled=2  },
		{ name="INV_TerrainBlock_Castle_LargeSideClip",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_ExtraLargeSideClip",	enabled=2  },
		{ name="INV_TER_Cliff_12x4_A",				enabled=2  },
		{ name="INV_TER_Cliff_12x4_A_Corner",			enabled=2  },
		{ name="INV_TER_Cliff_12x4_A_Short",			enabled=2  },
		{ name="INV_TER_Clip_LedgeRope_12X_A",			enabled=2  },
		{ name="INV_TerrainBlock_Castle_BridgeClip",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_BridgeWideClip",	enabled=2  },
		{ name="INV_Terrain_Castle_SmallBridgeClip",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_SmallEdgeClip",		enabled=2  },
		{ name="INV_TER_Clip_BridgeCurve_24x24x12_A",		enabled=2  },
		{ name="INV_TER_Clip_RevSBridge",			enabled=2  },
		{ name="INV_TER_Clip_Sbridge",				enabled=2  },
		{ name="INV_TER_Clip_BankCurve",			enabled=2  },
		{ name="INV_TER_Clip_CornerHill_Inner",			enabled=2  },
		{ name="INV_TER_Clip_CornerHill_Outer",			enabled=2  },
		{ name="INV_TerrainBlock_Castle_SlopeB_48X48",		enabled=2  },
		{ name="INV_TER_Clip_Slope_24x48x12",			enabled=2  },
		{ name="INV_TER_Clip_Slope_12x48x12",			enabled=2  },
		{ name="INV_BridgeSlope_24X48X12_A",			enabled=2  },
		{ name="INV_TER_Clip_LongRamp",				enabled=2  },
		{ name="INV_TerrainBlock_Castle_RampSideClip",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_RampStepClip",		enabled=2  },
		{ name="INV_TER_CliffSlope_24x4_A",			enabled=2  },
		{ name="INV_TER_CliffSlope_24x4_B",			enabled=2  },
		{ name="INV_RRO_TerrainBlock_Castle_RampRoundClip",	enabled=2  },
		{ name="INV_TerrainBlock_Castle_River_24X24",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_RiverBend_24X24",	enabled=2  },
		{ name="INV_TerrainBlock_Castle_RiverEnd_Clip",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_RiverEnd_24X24",	enabled=2  },
		{ name="INV_TER_Lake_48x48x24_A",			enabled=2  },
		{ name="INV_TerrainBlock_Castle_River_48X48",		enabled=2  },
		{ name="INV_TerrainBlock_Castle_WaterFall_24X24",	enabled=2  },
		{ name="INV_TerrainBlock_Castle_WaterFall_48X48",	enabled=2  },
		{ name="INV_TER_Mntn_24x24x24_01",			enabled=2  },
		{ name="INV_TER_Mntn_24X_B",				enabled=2  },
		{ name="INV_SETPIECE_Matterhorn",			enabled=2  },
		{ name="INV_TER_Clip_Tower",				enabled=2  },
		{ name="INV_TER_Cave_Tunnel_A",				enabled=2  },
		{ name="INV_TER_Cave_Tunnel_A_NoBeams",			enabled=2  },
		{ name="INV_TER_Cave_Deadend_A",			enabled=2  },
		{ name="INV_TER_Cave_Curve_A",				enabled=2  },
		{ name="INV_TER_Cave_Tsect_A",				enabled=2  },
		{ name="INV_TER_Cave_Intersect_A",			enabled=2  },
		{ name="INV_TER_Cave_Well_A",				enabled=2  },
		{ name="INV_TER_Cave_Cubefort_B",			enabled=2  },
		{ name="INV_TER_Cave_Cubefort_A",			enabled=2  },
		{ name="INV_TER_Cave_WaterfallDoor",			enabled=2  },
		{ name="INV_TER_Cave_CrystalCavern",			enabled=2  },
		{ name="INV_TER_Cave_TreasureGrotto",			enabled=2  },
		{ name="INV_TER_Canyon_Straight",			enabled=2  },
		{ name="INV_TER_Canyon_Deadend",			enabled=2  },
		{ name="INV_TER_Canyon_Curve",				enabled=2  },
		{ name="INV_TER_Canyon_3way",				enabled=2  },
		{ name="INV_TER_Canyon_4way",				enabled=2  },
		{ name="INV_TER_CanyonWall_4x8_A",			enabled=2  },
		{ name="INV_TER_CanyonWall_12x8_A",			enabled=2  },
		{ name="INV_TER_CanyonWall_24x8_A",			enabled=2  },
		{ name="INV_TER_CanyonWall_48x8_A",			enabled=2  },
		{ name="INV_TER_CanyonWallCurve_Inner_8x_A",		enabled=2  },
		{ name="INV_TER_CanyonWallCurve_Inner_16x_A",		enabled=2  },
		{ name="INV_TER_CanyonWallCurve_Inner_32x_A",		enabled=2  },
		{ name="INV_TER_CanyonWallCurve_Outer_8x_A",		enabled=2  },
		{ name="INV_TER_CanyonWallCurve_Outer_40x_A",		enabled=2  },
		{ name="INV_TER_CanyonWallCurve_Outer_48x_A",		enabled=2  },
		{ name="INV_TER_CanyonWallCurve_Outer_56x_A",		enabled=2  },
		{ name="INV_TER_Canyon_InsideCorner_A",			enabled=2  },
		{ name="INV_TER_Canyon_Side_24x8x24_A",			enabled=2  },
		{ name="INV_TER_Canyon_Side_24x8x24_B",			enabled=2  },
		{ name="INV_TER_Canyon_Side_Cave_A",			enabled=2  },
		{ name="INV_TER_Canyon_Side_Bridge_A",			enabled=2  },
		{ name="INV_TER_Canyon_Side_Curve_A",			enabled=2  },
		{ name="INV_TER_BalancingChunk_24x_A",			enabled=2  },
		{ name="INV_TER_Sewer_Tunnel_12x_A",			enabled=2  },
		{ name="INV_TER_Sewer_Deadend_12x_A",			enabled=2  },
		{ name="INV_TER_Sewer_Curve_12x_A",			enabled=2  },
		{ name="INV_TER_Sewer_3way_12x_A",			enabled=2  },
		{ name="INV_TER_Sewer_4way_12x_A",			enabled=2  },
		{ name="INV_TER_Sewer_Manhole_12x_A",			enabled=2  },
	},

	LOCKS = 
	{
		{ name="XUP_Blaster",			state="AVAILABLE"  },
		{ name="UP_MidwayManiaGun",		state="AVAILABLE"  },
		{ name="UP_StitchBlaster",		state="AVAILABLE"  },
		{ name="UP_FlamingPumpkin",		state="AVAILABLE"  },
		{ name="UP_BaseballGun",		state="AVAILABLE"  },
		{ name="UP_CherryBomb",			state="AVAILABLE"  },
		{ name="UP_CherryBomb_HD",		state="AVAILABLE"  },
		{ name="UP_FrozenHook",			state="AVAILABLE"  },
		{ name="UP_FireworkCannon",		state="AVAILABLE"  },
		{ name="UP_FlintLock",			state="AVAILABLE"  },
		{ name="UP_Blunderbuss",		state="AVAILABLE"  },
		{ name="UP_PixarBalls",			state="AVAILABLE"  },
		{ name="UP_BigPixarBalls",		state="AVAILABLE"  },
		{ name="UP_Blaster",			state="AVAILABLE"  },
		{ name="UP_MedicineBall",		state="AVAILABLE"  },
		{ name="UP_StickyHand",			state="AVAILABLE"  },
		{ name="UP_Invisibility",		state="AVAILABLE"  },
		{ name="UP_PirateBomb",			state="AVAILABLE"  },
		{ name="UP_GrapplingHook",		state="AVAILABLE"  },
		{ name="UP_FaintBallGun",		state="AVAILABLE"  },
		{ name="UP_GlowUrchin",			state="AVAILABLE"  },
		{ name="UP_TPGun",			state="AVAILABLE"  },
		{ name="UP_ToxicBall",			state="AVAILABLE"  },
		{ name="UP_DarkwingGun",		state="AVAILABLE"  },
		{ name="UP_LewZealandFish",		state="AVAILABLE"  },
		{ name="UP_MabelCatFist",		state="AVAILABLE"  },
		{ name="UP_SrgntCalhounsBlaster",	state="AVAILABLE"  },
		{ name="UP_VibraniumKnives",		state="AVAILABLE"  },
		{ name="UP_Diffusinator",		state="AVAILABLE"  },
		{ name="UP_GoblinGrenade",		state="AVAILABLE"  },
		{ name="UP_GRChainWhip",		state="AVAILABLE"  },
		{ name="UP_SwordPack",			state="AVAILABLE"  },
		{ name="UP_FryingPanPack",		state="AVAILABLE"  },
		{ name="UP_FlamingoMalletPack",		state="AVAILABLE"  },
		{ name="UP_UpCanePack",			state="AVAILABLE"  },
		{ name="UP_StitchSurfBoard",		state="AVAILABLE"  },
		{ name="UP_ShovelPack",			state="AVAILABLE"  },
		{ name="UP_WallEBooster",		state="AVAILABLE"  },
		{ name="UP_TronDiscPack",		state="AVAILABLE"  },
		{ name="UP_InvisibilityPack",		state="AVAILABLE"  },
		{ name="UP_SwordInStonePack",		state="AVAILABLE"  },
		{ name="UP_GlowingSword",		state="AVAILABLE"  },
		{ name="UP_JetPack",			state="AVAILABLE"  },
		{ name="UP_Booster",			state="AVAILABLE"  },
		{ name="UP_Cape",			state="AVAILABLE"  },
		{ name="UP_HoverBoard",			state="AVAILABLE"  },
		{ name="UP_CondorManWings",		state="AVAILABLE"  },
		{ name="UP_MonsterPack",		state="AVAILABLE"  },
		{ name="UP_Talisman",			state="AVAILABLE"  },
		{ name="UP_Dynamite",			state="AVAILABLE"  },
		{ name="UP_SpiritHorse",		state="AVAILABLE"  },
		{ name="UP_SpiritWarrior",		state="AVAILABLE"  },
		{ name="UP_SolarBoardPack",		state="AVAILABLE"  },
		{ name="UP_DrStrangePack",		state="AVAILABLE"  },
		{ name="UP_FalconWings",		state="AVAILABLE"  },
		{ name="UP_GoblinGlider",		state="AVAILABLE"  },
		{ name="UP_JackOLanternGlider",		state="AVAILABLE"  },
		{ name="UP_SpiderGlider",		state="AVAILABLE"  },
		{ name="UP_AladdinsCarpet",		state="AVAILABLE"  },
	},
}
															 

