---------------------------[ RumpusScenario ] -----------------------------------
--
-- This system was created to set specific recipe card and inventory availability for a gameplay scenario, based on world name
-- 
-- The intended use is for the game to save state before entering a scenario, setting the inventory
-- and recipe card configuation needed for the scenario, allowing the scenario to play out, returning to 
-- main game and then forcing a save game load to restore the previous inventory state. 
--
-- ONE SHOULD NOT ALLOW SAVE GAMES TO HAPPEN DURING AN ADVENTURE OTHERWISE USER DATA WILL GET LOST!
--
-- The useage of this file is simple, within the Data section one creates a new data section with the same 
-- name as the scenario world name (holoEmpty for example). Within that world name section there are multiple 
-- commands and sections to set the state of various things. Non-Programmers may need to consult with a programmer
-- to get the proper lock names or stat set names depending on what data they want to setup. Only data that matches
-- the current level name will be used
--
-- COMMANDS: 
--	HIDE_ALL_INVENTORY - removes all inventory items from inventory ribbon, does NOT change availibility or count to existing items
-- 	SHOW_ALL_INVENTORY - adds all inventory items to the inventory ribbon, does NOT change availibility or count of existing items
--	LOCK_ALL_INVENTORY - locks all inventory, sets availability count to 0
-- 	UNLOCK_ALL_INVENTORY - unlocks all inventory items and assigns a availablity count of 1
--	SET_LOCKS_BY_TYPE - takes a type of lock, and sets it to the specificed state
--	PURCHASE_ALL_UNLOCKED_RECIPECARDS - will purchase all items for all unlocked recipe cards
--	RIBBON_SELECT - given an inventory item name, the ribbon will come up with this item selected initially
--
-- LOCKS:
--	Given a lock name, it will set it to the specified state
--
-- STATS:
--	Given the stat set name, and stat name, it will set the stat to the value specified
--
-- INVENTORY_ITEM_STATE:
-- 	Given an inventory item name, it will set the state and count to what is specified.
--    Enabled=0 (don't show even if unlocked), 1 (show if unlocked), 2 (show even if locked)
--
-- MIX_RECIPE_CARDS:
--	Given a recipe card name, it will purchase and mix this card.
-- 
--
-- Recommended usage:
-- 	To keep things simple, in most cases for a scenario or test case, one should use the commands to 
-- 	make everything unavailable, then set specific things to be available. 



Data = 
{
	RUMPUS_CHESTDROP_TOY =
	{
		{	
			LootChest_Brave_Lvl1 =	
			{	
				{ name="Dun_SparkRewardHigh", chance=1.0, amount=1 },
				{ name="SK_Brave_Green_MagicWand_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_MagicWand_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Orange_MagicWand_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_Harpoon_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_Harpoon_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_Harpoon_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_MagicStaff_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_MagicStaff_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_MagicStaff_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_ThowingDagger_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ThowingDagger_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ThowingDagger_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_BlowDart_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_BlowDart_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_BlowDart_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_FryingPan_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_FryingPan_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_FryingPan_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_Boomarang_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_Boomarang_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_Boomarang_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_BowArrow_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_BowArrow_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_BowArrow_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_MagicPotion_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_MagicPotion_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_MagicPotion_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_IceCrystal_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_IceCrystal_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Orange_IceCrystal_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_Sling_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_Sling_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Orange_Sling_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_CelticShield_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_CelticShield_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_CelticShield_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_Healing_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_Healing_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_Healing_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_WarHammer_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_WarHammer_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_WarHammer_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_BasketMushrooms_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_BasketMushrooms_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_BasketMushrooms_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_SpellBook_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_SpellBook_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Orange_SpellBook_AC", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_LeatherCap_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_LeatherCap_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_LeatherCap_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_DingedHelmet_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_DingedHelmet_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_DingedHelmet_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_QueenCrown_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_QueenCrown_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_QueenCrown_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_ChefHat_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ChefHat_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ChefHat_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_MeridaHair_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_MeridaHair_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_MeridaHair_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_MeridaHood_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_MeridaHood_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_MeridaHood_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_WeldingMask_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_WeldingMask_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_WeldingMask_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_WitchsHair_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_WitchsHair_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_WitchsHair_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_Dunbroch_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_Dunbroch_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_Dunbroch_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_Dingwall_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_Dingwall_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Orange_Dingwall_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_Macintosh_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_Macintosh_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Orange_Macintosh_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_HelmetMacGuffin_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_HelmetMacGuffin_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_HelmetMacGuffin_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_HornedHelmet_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_HornedHelmet_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_HornedHelmet_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_WingedHelm_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_WingedHelm_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_WingedHelm_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_GreatHelm_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_GreatHelm_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Orange_GreatHelm_HR", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_ArmorBasic1_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ArmorBasic1_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ArmorBasic1_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_ArmorBasic2_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ArmorBasic2_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ArmorBasic2_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_ArmorBasic3_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ArmorBasic3_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ArmorBasic3_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_ArmorBasic4_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ArmorBasic4_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ArmorBasic4_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_ArmorBasic5_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ArmorBasic5_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ArmorBasic5_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_ArmorStandard1_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ArmorStandard1_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ArmorStandard1_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_ArmorStandard2_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ArmorStandard2_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ArmorStandard2_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_ArmorStandard3_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ArmorStandard3_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ArmorStandard3_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_ArmorStandard4_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ArmorStandard4_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ArmorStandard4_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ArmorStandard5_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ArmorStandard5_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Orange_ArmorStandard5_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ArmorAdvanced1_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ArmorAdvanced1_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Orange_ArmorAdvanced1_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_ArmorAdvanced2_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ArmorAdvanced2_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ArmorAdvanced2_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_ArmorAdvanced3_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ArmorAdvanced3_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ArmorAdvanced3_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Green_ArmorAdvanced4_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ArmorAdvanced4_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ArmorAdvanced4_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Blue_ArmorAdvanced5_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Purple_ArmorAdvanced5_B", chance=100.0, amount=1 },
				{ name="SK_Brave_Orange_ArmorAdvanced5_B", chance=100.0, amount=1 },
			},	
			LootChest_MysteryPackageChest =
			{
				{ name="TOY_BRV_Mystery_Package_A", chance=80.0, amount=1 },
				{ name="Dun_SparkRewardHigh", chance=20.0, amount=1 },
			},
			LootChest_SidekickDoorA =
			{
				{ name="PU_SparkCapsule", chance=50.0, amount=1 },
				{ name="PU_SuperMeterCapsule", chance=35.0, amount=1 },
				{ name="PU_HealthCapsule", chance=8.0, amount=1 },
				{ name="PU_ExperienceCapsule", chance=2.0, amount=1 },
				{ name="TOY_BRV_Mystery_Package_A", chance=10.0, amount=1 },
			},
			LootChest_SidekickDoorB =
			{
				{ name="PU_SparkCapsule", chance=50.0, amount=1 },
				{ name="PU_SuperMeterCapsule", chance=35.0, amount=1 },
				{ name="PU_HealthCapsule", chance=8.0, amount=1 },
				{ name="PU_ExperienceCapsule", chance=2.0, amount=1 },
				{ name="TOY_BRV_Mystery_Package_A", chance=10.0, amount=1 },
			},
			LootChest_SidekickDoorC =
			{
				{ name="PU_SparkCapsule", chance=50.0, amount=1 },
				{ name="PU_SuperMeterCapsule", chance=35.0, amount=1 },
				{ name="PU_HealthCapsule", chance=8.0, amount=1 },
				{ name="PU_ExperienceCapsule", chance=2.0, amount=1 },
				{ name="TOY_BRV_Mystery_Package_A", chance=10.0, amount=1 },
			},
			LootChest_SidekickDoorD =
			{
				{ name="PU_SparkCapsule", chance=50.0, amount=1 },
				{ name="PU_SuperMeterCapsule", chance=35.0, amount=1 },
				{ name="PU_HealthCapsule", chance=8.0, amount=1 },
				{ name="PU_ExperienceCapsule", chance=2.0, amount=1 },
				{ name="TOY_BRV_Mystery_Package_A", chance=10.0, amount=1 },
			},
			LootChest_SidekickDoorE =
			{
				{ name="PU_SparkCapsule", chance=50.0, amount=1 },
				{ name="PU_SuperMeterCapsule", chance=35.0, amount=1 },
				{ name="PU_HealthCapsule", chance=8.0, amount=1 },
				{ name="PU_ExperienceCapsule", chance=2.0, amount=1 },
				{ name="TOY_BRV_Mystery_Package_A", chance=10.0, amount=1 },
			},
			LootChest_SidekickSeekSpotA =
			{
				{ name="Dun_SparkRewardLow", chance=55.0, amount=1 },
				{ name="PU_SuperMeter", chance=30.0, amount=10 },
				{ name="PU_Health", chance=10.0, amount=15 },
				{ name="PU_Experience", chance=4.0, amount=10 },
				{ name="TOY_BRV_Mystery_Package_A", chance=2.0, amount=1 },
			},
			LootChest_SidekickSeekSpotB =
			{
				{ name="Dun_SparkRewardLow", chance=55.0, amount=1 },
				{ name="PU_SuperMeter", chance=30.0, amount=10 },
				{ name="PU_Health", chance=10.0, amount=15 },
				{ name="PU_Experience", chance=4.0, amount=10 },
				{ name="TOY_BRV_Mystery_Package_A", chance=2.0, amount=1 },
			},
			LootChest_SidekickSeekSpotC =
			{
				{ name="Dun_SparkRewardLow", chance=55.0, amount=1 },
				{ name="PU_SuperMeter", chance=30.0, amount=10 },
				{ name="PU_Health", chance=10.0, amount=15 },
				{ name="PU_Experience", chance=4.0, amount=10 },
				{ name="TOY_BRV_Mystery_Package_A", chance=2.0, amount=1 },
			},
			LootChest_SidekickSeekSpotD =
			{
				{ name="Dun_SparkRewardLow", chance=55.0, amount=1 },
				{ name="PU_SuperMeter", chance=30.0, amount=10 },
				{ name="PU_Health", chance=10.0, amount=15 },
				{ name="PU_Experience", chance=4.0, amount=10 },
				{ name="TOY_BRV_Mystery_Package_A", chance=2.0, amount=1 },
			},
			LootChest_SidekickSeekSpotE =
			{
				{ name="Dun_SparkRewardLow", chance=55.0, amount=1 },
				{ name="PU_SuperMeter", chance=30.0, amount=10 },
				{ name="PU_Health", chance=10.0, amount=15 },
				{ name="PU_Experience", chance=4.0, amount=10 },
				{ name="TOY_BRV_Mystery_Package_A", chance=2.0, amount=1 },
			},
		}
	},
}
															 

