---------------------------[ RumpusScenario ] -----------------------------------
--
-- This system was created to set specific recipe card and inventory availability for a gameplay scenario, based on world name
-- 
-- The intended use is for the game to save state before entering a scenario, setting the inventory
-- and recipe card configuation needed for the scenario, allowing the scenario to play out, returning to 
-- main game and then forcing a save game load to restore the previous inventory state. 
--
-- ONE SHOULD NOT ALLOW SAVE GAMES TO HAPPEN DURING AN ADVENTURE OTHERWISE USER DATA WILL GET LOST!
--
-- The useage of this file is simple, within the Data section one creates a new data section with the same 
-- name as the scenario world name (holoEmpty for example). Within that world name section there are multiple 
-- commands and sections to set the state of various things. Non-Programmers may need to consult with a programmer
-- to get the proper lock names or stat set names depending on what data they want to setup. Only data that matches
-- the current level name will be used
--
-- COMMANDS: 
--	HIDE_ALL_INVENTORY - removes all inventory items from inventory ribbon, does NOT change availibility or count to existing items
-- 	SHOW_ALL_INVENTORY - adds all inventory items to the inventory ribbon, does NOT change availibility or count of existing items
--	LOCK_ALL_INVENTORY - locks all inventory, sets availability count to 0
-- 	UNLOCK_ALL_INVENTORY - unlocks all inventory items and assigns a availablity count of 1
--	SET_LOCKS_BY_TYPE - takes a type of lock, and sets it to the specificed state
--	PURCHASE_ALL_UNLOCKED_RECIPECARDS - will purchase all items for all unlocked recipe cards
--	RIBBON_SELECT - given an inventory item name, the ribbon will come up with this item selected initially
--
-- LOCKS:
--	Given a lock name, it will set it to the specified state
--
-- STATS:
--	Given the stat set name, and stat name, it will set the stat to the value specified
--
-- INVENTORY_ITEM_STATE:
-- 	Given an inventory item name, it will set the state and count to what is specified.
--    Enabled=0 (don't show even if unlocked), 1 (show if unlocked), 2 (show even if locked)
--
-- MIX_RECIPE_CARDS:
--	Given a recipe card name, it will purchase and mix this card.
-- 
--
-- Recommended usage:
-- 	To keep things simple, in most cases for a scenario or test case, one should use the commands to 
-- 	make everything unavailable, then set specific things to be available. 



Data = 
{
	RUMPUS_CHESTDROP_TOY =
	{
		{	
			LootChest_Kyln_Lvl1 =	
			{	
				{ name="SK_Kyln_Green_Healing_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_Healing_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_Blaster_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_Blaster_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Orange_Blaster_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_EnergyHarpoon_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_EnergyHarpoon_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_EnergyHarpoon_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_LaserBeam_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_LaserBeam_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_LaserBeam_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_EnergyShuriken_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_EnergyShuriken_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_EnergyShuriken_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_MachineGun_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_MachineGun_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_MachineGun_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_Boomarang_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_Boomarang_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_Boomarang_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_RicochetDisc_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_RicochetDisc_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_RicochetDisc_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_EnergyBow_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_EnergyBow_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_EnergyBow_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_RocketLauncher_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_RocketLauncher_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_FreezeBomb_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_FreezeBomb_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_GrenadeLauncher_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_GrenadeLauncher_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_RiotEnergyShield_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_RiotEnergyShield_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_EnergyHammer_AC", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_HelmWhite1_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_HelmWhite1_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_HelmWhite1_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_HelmWhite2_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_HelmWhite2_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_HelmWhite2_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_HelmWhite3_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_HelmWhite3_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_HelmWhite3_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_HelmWhite4_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_HelmWhite4_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_HelmWhite4_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_HelmWhite5_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_HelmWhite5_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_HelmWhite5_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_HelmGrey1_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_HelmGrey1_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_HelmGrey1_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_HelmGrey2_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_HelmGrey2_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_HelmGrey2_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_HelmGrey3_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_HelmGrey3_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_HelmGrey3_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_HelmGrey4_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_HelmGrey4_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_HelmGrey4_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_HelmGrey5_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_HelmGrey5_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Orange_HelmGrey5_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_HelmRed1_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_HelmRed1_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Orange_HelmRed1_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_HelmRed2_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_HelmRed2_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_HelmRed2_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_HelmRed3_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_HelmRed3_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_HelmRed3_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_HelmRed4_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_HelmRed4_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_HelmRed4_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_HelmRed5_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_HelmRed5_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Orange_HelmRed5_HR", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_ArmorWhite1_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_ArmorWhite1_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_ArmorWhite1_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_ArmorWhite2_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_ArmorWhite2_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_ArmorWhite2_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_ArmorWhite3_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_ArmorWhite3_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_ArmorWhite3_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_ArmorWhite4_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_ArmorWhite4_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_ArmorWhite4_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_ArmorWhite5_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_ArmorWhite5_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_ArmorWhite5_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_ArmorGrey1_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_ArmorGrey1_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_ArmorGrey1_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_ArmorGrey2_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_ArmorGrey2_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_ArmorGrey2_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_ArmorGrey3_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_ArmorGrey3_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_ArmorGrey3_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_ArmorGrey4_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_ArmorGrey4_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_ArmorGrey4_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_ArmorGrey5_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_ArmorGrey5_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Orange_ArmorGrey5_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_ArmorRed1_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_ArmorRed1_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Orange_ArmorRed1_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_ArmorRed2_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_ArmorRed2_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_ArmorRed2_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_ArmorRed3_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_ArmorRed3_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_ArmorRed3_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Green_ArmorRed4_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_ArmorRed4_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_ArmorRed4_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Blue_ArmorRed5_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Purple_ArmorRed5_B", chance=100.0, amount=1 },
				{ name="SK_Kyln_Orange_ArmorRed5_B", chance=100.0, amount=1 },
				{ name="Dun_SparkRewardHigh", chance=1.0, amount=1 },
			},	
			LootChest_MysteryPackageChest =
			{
				{ name="TOY_KLN_Mystery_Package_A", chance=80.0, amount=1 },
				{ name="Dun_SparkRewardHigh", chance=20.0, amount=1 },
			},
			LootChest_SidekickDoorA =
			{
				{ name="PU_SparkCapsule", chance=50.0, amount=1 },
				{ name="PU_SuperMeterCapsule", chance=35.0, amount=1 },
				{ name="PU_HealthCapsule", chance=8.0, amount=1 },
				{ name="PU_ExperienceCapsule", chance=2.0, amount=1 },
				{ name="TOY_KLN_Mystery_Package_A", chance=10.0, amount=1 },
			},
			LootChest_SidekickDoorB =
			{
				{ name="PU_SparkCapsule", chance=50.0, amount=1 },
				{ name="PU_SuperMeterCapsule", chance=35.0, amount=1 },
				{ name="PU_HealthCapsule", chance=8.0, amount=1 },
				{ name="PU_ExperienceCapsule", chance=2.0, amount=1 },
				{ name="TOY_KLN_Mystery_Package_A", chance=10.0, amount=1 },
			},
			LootChest_SidekickDoorC =
			{
				{ name="PU_SparkCapsule", chance=50.0, amount=1 },
				{ name="PU_SuperMeterCapsule", chance=35.0, amount=1 },
				{ name="PU_HealthCapsule", chance=8.0, amount=1 },
				{ name="PU_ExperienceCapsule", chance=2.0, amount=1 },
				{ name="TOY_KLN_Mystery_Package_A", chance=10.0, amount=1 },
			},
			LootChest_SidekickDoorD =
			{
				{ name="PU_SparkCapsule", chance=50.0, amount=1 },
				{ name="PU_SuperMeterCapsule", chance=35.0, amount=1 },
				{ name="PU_HealthCapsule", chance=8.0, amount=1 },
				{ name="PU_ExperienceCapsule", chance=2.0, amount=1 },
				{ name="TOY_KLN_Mystery_Package_A", chance=10.0, amount=1 },
			},
			LootChest_SidekickDoorE =
			{
				{ name="PU_SparkCapsule", chance=50.0, amount=1 },
				{ name="PU_SuperMeterCapsule", chance=35.0, amount=1 },
				{ name="PU_HealthCapsule", chance=8.0, amount=1 },
				{ name="PU_ExperienceCapsule", chance=2.0, amount=1 },
				{ name="TOY_KLN_Mystery_Package_A", chance=10.0, amount=1 },
			},
			LootChest_SidekickSeekSpotA =
			{
				{ name="Dun_SparkRewardLow", chance=55.0, amount=1 },
				{ name="PU_SuperMeter", chance=30.0, amount=10 },
				{ name="PU_Health", chance=10.0, amount=15 },
				{ name="PU_Experience", chance=4.0, amount=10 },
				{ name="TOY_KLN_Mystery_Package_A", chance=2.0, amount=1 },
			},
			LootChest_SidekickSeekSpotB =
			{
				{ name="Dun_SparkRewardLow", chance=55.0, amount=1 },
				{ name="PU_SuperMeter", chance=30.0, amount=10 },
				{ name="PU_Health", chance=10.0, amount=15 },
				{ name="PU_Experience", chance=4.0, amount=10 },
				{ name="TOY_KLN_Mystery_Package_A", chance=2.0, amount=1 },
			},
			LootChest_SidekickSeekSpotC =
			{
				{ name="Dun_SparkRewardLow", chance=55.0, amount=1 },
				{ name="PU_SuperMeter", chance=30.0, amount=10 },
				{ name="PU_Health", chance=10.0, amount=15 },
				{ name="PU_Experience", chance=4.0, amount=10 },
				{ name="TOY_KLN_Mystery_Package_A", chance=2.0, amount=1 },
			},
			LootChest_SidekickSeekSpotD =
			{
				{ name="Dun_SparkRewardLow", chance=55.0, amount=1 },
				{ name="PU_SuperMeter", chance=30.0, amount=10 },
				{ name="PU_Health", chance=10.0, amount=15 },
				{ name="PU_Experience", chance=4.0, amount=10 },
				{ name="TOY_KLN_Mystery_Package_A", chance=2.0, amount=1 },
			},
			LootChest_SidekickSeekSpotE =
			{
				{ name="Dun_SparkRewardLow", chance=55.0, amount=1 },
				{ name="PU_SuperMeter", chance=30.0, amount=10 },
				{ name="PU_Health", chance=10.0, amount=15 },
				{ name="PU_Experience", chance=4.0, amount=10 },
				{ name="TOY_KLN_Mystery_Package_A", chance=2.0, amount=1 },
			},
		}
	},
}
															 

