---------------------------[ RumpusScenario ] -----------------------------------
--
-- This system was created to set specific recipe card and inventory availability for a gameplay scenario, based on world name
-- 
-- The intended use is for the game to save state before entering a scenario, setting the inventory
-- and recipe card configuation needed for the scenario, allowing the scenario to play out, returning to 
-- main game and then forcing a save game load to restore the previous inventory state. 
--
-- ONE SHOULD NOT ALLOW SAVE GAMES TO HAPPEN DURING AN ADVENTURE OTHERWISE USER DATA WILL GET LOST!
--
-- The useage of this file is simple, within the Data section one creates a new data section with the same 
-- name as the scenario world name (holoEmpty for example). Within that world name section there are multiple 
-- commands and sections to set the state of various things. Non-Programmers may need to consult with a programmer
-- to get the proper lock names or stat set names depending on what data they want to setup. Only data that matches
-- the current level name will be used
--
-- COMMANDS: 
--	HIDE_ALL_INVENTORY - removes all inventory items from inventory ribbon, does NOT change availibility or count to existing items
-- 	SHOW_ALL_INVENTORY - adds all inventory items to the inventory ribbon, does NOT change availibility or count of existing items
--	LOCK_ALL_INVENTORY - locks all inventory, sets availability count to 0
-- 	UNLOCK_ALL_INVENTORY - unlocks all inventory items and assigns a availablity count of 1
--	SET_LOCKS_BY_TYPE - takes a type of lock, and sets it to the specificed state
--	PURCHASE_ALL_UNLOCKED_RECIPECARDS - will purchase all items for all unlocked recipe cards
--	RIBBON_SELECT - given an inventory item name, the ribbon will come up with this item selected initially
--
-- LOCKS:
--	Given a lock name, it will set it to the specified state
--
-- STATS:
--	Given the stat set name, and stat name, it will set the stat to the value specified
--
-- INVENTORY_ITEM_STATE:
-- 	Given an inventory item name, it will set the state and count to what is specified.
--    Enabled=0 (don't show even if unlocked), 1 (show if unlocked), 2 (show even if locked)
--
-- MIX_RECIPE_CARDS:
--	Given a recipe card name, it will purchase and mix this card.
-- 
--
-- Recommended usage:
-- 	To keep things simple, in most cases for a scenario or test case, one should use the commands to 
-- 	make everything unavailable, then set specific things to be available. 



Data = 
{
	RUMPUS_STOREFRONT_TOY =
		{
			{	
				Store_DefendWaveKit01 =
				{
					ITEMS =
					{
						{ name="INV_TOY_PopupTurret",		buycost=10.0,  sellcost=10.0},
						{ name="INV_TOY_FloorSpikes",		buycost=10.0,  sellcost=10.0},
						{ name="INV_TOY_TRIPWIRE",		buycost=10.0,  sellcost=10.0},
						{ name="INV_NPC_TB_TANGLED_GUARD",	buycost=10.0,  sellcost=10.0},
					},					
					CUSTOMFIELDS =
					{
	-- Valid economy icon names
	-- TB_EconomyToy_Infinity
	-- TB_EconomyToy_Gold
	-- TB_EconomyToy_Gems
	-- TB_EconomyToy_Marvel
	-- TB_EconomyToy_Flowers
	-- TB_EconomyToy_Balloon

						{ field="600",	icon="TB_EconomyToy_Gold" },
					},
				},
				Store_DefendWaveKit02 =
				{
					ITEMS =
					{
						{ name="INV_TOY_PopupTurret",		buycost=400.0,  sellcost=400.0 },
						{ name="INV_TOY_FloorSpikes",		buycost=600.0,  sellcost=600.0 },
						{ name="INV_TOY_TRIPWIRE",		buycost=100.0,  sellcost=100.0 },
						{ name="INV_NPC_TB_TANGLED_GUARD",	buycost=100.0,  sellcost=100.0 },
					},
				},
			}
		},
		RUMPUS_ECONOMY_TOY =
		{
			{	
				Econ_DefendWaveKit01 =
				{
					{ currType=1, amount=30 },
				},
				Econ_DefendWaveKit02 =
				{
					{ currType=2, amount=600 },
				},
			}
		},
		RUMPUS_LOOT_TOY =
		{
			{
				LootToy_DefendWaveKit01 =	-- Toy name
				{
					POOLNAME01 =		-- Toy's loot pool name
					{
						ENEMYS = 
						{
							{ name = "INV_NPC_TB_ALADDIN_GUARD" },
						},
						LOOT =
						{
							{ TYPE = "ECONOMY",		CHANCE=100.0, amount=50 },
						}, 
					},
				},
			},
		},

	LEVEL_1 =
	{
		COMMANDS =
		{
			{ name = "HIDE_ALL_INVENTORY" },
		},
	
		INVENTORY_ITEM_STATE = 	
		{
			{ name="INV_Toy_Triggerplate",		enabled=2  },
			{ name="INV_Toy_Button",			enabled=2  },
							
		},
	},

	LEVEL_2 =
	{
		COMMANDS =
		{
			{ name = "HIDE_ALL_INVENTORY" },
		},

		INVENTORY_ITEM_STATE = 	
		{
			{ name="INV_Toy_Triggerplate",		enabled=2  },
			{ name="INV_TOY_TriggerVolume",		enabled=2  },
			{ name="INV_Toy_Button",		enabled=2  },
			{ name="INV_TOY_JET_BARREL",		enabled=2  },
			{ name="INV_TOY_UpVent",		enabled=2  },
			{ name="INV_Toy_PinballBumper",		enabled=2  },
			{ name="INV_Toy_PinballBouncer",	enabled=2  },
			{ name="INV_TOY_PinballFlipper_L",	enabled=2  },
			{ name="INV_TOY_PinballFlipper_R",	enabled=2  },
			{ name="INV_TRK_Rail_Straight",		enabled=2  },
			{ name="INV_TRK_Rail_StraightShort",	enabled=2  },
			{ name="INV_TRK_Rail_Bump",		enabled=2  },
			{ name="INV_TRK_Rail_Dip",		enabled=2  },
			{ name="INV_TRK_Rail_Ramp",		enabled=2  },
			{ name="INV_TRK_Rail_Ramp_Sharp",	enabled=2  },
			{ name="INV_TRK_Rail_RampBlend_A",	enabled=2  },
			{ name="INV_TRK_Rail_RampBlend_B",	enabled=2  },
			{ name="INV_PRANK_Launcher_A_RR",	enabled=2  },
			{ name="INV_PRANK_Launcher_B_RR",	enabled=2  },
			{ name="INV_PRANK_Launcher_C_RR",	enabled=2  },
			{ name="INV_PRANK_Launcher_D_RR",	enabled=2  },
			{ name="INV_PRANK_Launcher_G_RR",	enabled=2  },
		},
	},
	
							
	LEVEL_3 =
	{
		COMMANDS =
		{
			{ name = "HIDE_ALL_INVENTORY" },
		},

		INVENTORY_ITEM_STATE = 	
		{
			{ name="INV_Toy_Triggerplate",			enabled=2  },
			{ name="INV_BRS_TerrainBrushStart",		enabled=2  },
			{ name="INV_BRS_TrackBrushStart",		enabled=2  },
			{ name="INV_BRS_TreehouseBrushStart",		enabled=2  },
		},
	},
	
	LEVEL_4 =
	{
		COMMANDS =
		{
			{ name = "HIDE_ALL_INVENTORY" },
		},

		INVENTORY_ITEM_STATE = 	
		{
			{ name="INV_Toy_Triggerplate",			enabled=2  },
			{ name="INV_BRS_PirateHouse_BrushHead",		enabled=2  },
			{ name="INV_BRS_CastleWall_BrushHead",		enabled=2  },
			{ name="INV_BRS_RailSlide_BrushHead",		enabled=2  },
		},
	},
	
	LEVEL_5 =
	{
		COMMANDS =
		{
			{ name = "SHOW_ALL_INVENTORY" },
		},
									
	},
	
	
	LEVEL_6 =
	{
		COMMANDS =
		{
			{ name = "HIDE_ALL_INVENTORY" },
		},

		INVENTORY_ITEM_STATE = 	
		{
			{ name="INV_SETPIECE_Onboarding",			enabled=2  },
		},
	},
}
															 

